package com.datacloudsec.scan.tasks.scheduler.job.task;

import com.datacloudsec.scan.cache.PoliciesSingleton;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.AlarmlogMapper;
import com.datacloudsec.scan.dao.ConfigMapper;
import com.datacloudsec.scan.dao.WebBugMapper;
import com.datacloudsec.scan.dao.WebMapper;
import com.datacloudsec.scan.dao.WebPoliciesMapper;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.handler.SuyanWebscan;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.service.IReport;
import com.datacloudsec.scan.service.IWeb;
import com.datacloudsec.scan.service.impl.EngineService;
import com.datacloudsec.scan.service.impl.WebService;
import com.datacloudsec.scan.tasks.scheduler.job.AlermJob;
import com.datacloudsec.scan.tasks.scheduler.job.SysLogJob;
import com.datacloudsec.utils.ComputeTextUtil;
import com.datacloudsec.utils.FtpUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.KafkaUtil;
import com.datacloudsec.utils.MybatisUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.SecretUtil;
import it.sauronsoftware.ftp4j.FTPClient;
import java.io.File;
import java.io.UnsupportedEncodingException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.ibatis.session.SqlSession;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_tasks_scheduler_job_task.jar:com/datacloudsec/scan/tasks/scheduler/job/task/WebTask.class */
public class WebTask {
    private static final int WEB_PX_LIMIT = 200;
    private static final int WEB_WX_LIMIT = 200;
    private static final int WEB_SM_LIMIT = 100;
    public static final String TEMP_FILE_NAME = "temp";
    public static final String OLD_BUG_NAME = "oldbug";
    private static final Logger LOG = Logger.getLogger(WebTask.class);
    private static IWeb webService = (IWeb) InstanceUtil.newServiceInstance(WebService.class);
    private static AlarmlogMapper alarmlogMapper = (AlarmlogMapper) InstanceUtil.newDaoInstance(AlarmlogMapper.class);
    private static ConfigMapper configMapper = (ConfigMapper) InstanceUtil.newDaoInstance(ConfigMapper.class);
    private static IEngine engine = new EngineService();
    public static final Map<String, String> WEB_LEVEL = new HashMap<String, String>() { // from class: com.datacloudsec.scan.tasks.scheduler.job.task.WebTask.1
        private static final long serialVersionUID = 1;

        {
            put("High", "高危");
            put("Medium", "中危");
            put("Low", "低危");
            put("Info", "信息");
        }
    };

    public static void webAvailScanSync(Map<String, Object> device) {
        Map<String, Object> waitingDev;
        Map<Object, Object> availMap;
        if (device == null) {
            return;
        }
        SqlSession session = null;
        try {
            try {
                WebMapper webMapper = (WebMapper) InstanceUtil.newDaoInstance(WebMapper.class);
                Integer deviceid = ObjectUtil.getInt(device.get("id"));
                Task task = webMapper.getTaskById(ObjectUtil.getInt(device.get("taskId")));
                String taskDest = task.getDest();
                Map<String, Object> engResult = engine.webGetResult(ObjectUtil.getString(device.get("availEngineid"), (String) null), ObjectUtil.getInt(device.get("availEid"), 0), 0, 0, 0, 0, 0, 0);
                Map<String, Object> result = (Map) engResult.get("result");
                String error = ObjectUtil.getString(engResult.get("error"), (String) null);
                Map<String, Object> serverInfo = (Map) result.get("serverInfo");
                if (serverInfo == null) {
                    if (0 != 0) {
                        session.close();
                        return;
                    }
                    return;
                }
                String state = ObjectUtil.getString(serverInfo.get("state"), "");
                if (StringUtils.isBlank(state)) {
                    if (0 != 0) {
                        session.close();
                        return;
                    }
                    return;
                }
                Map<String, Object> progress = (Map) result.get("progress");
                double totalProgress = ObjectUtil.getDouble(progress.get("totalProgress"), 0.0d);
                session = MybatisUtil.sqlSessionFactory.openSession(true);
                WebBugMapper bugMapper = (WebBugMapper) session.getMapper(WebBugMapper.class);
                Integer status = null;
                if (taskDest.contains("avail") && serverInfo != null) {
                    status = 2;
                    String remoteIp = ObjectUtil.getString(serverInfo.get("remoteIp"), "", WEB_SM_LIMIT);
                    String remoteIp2 = (StringUtils.isNotBlank(remoteIp) && ",".equals(remoteIp.substring(remoteIp.length() - 1))) ? remoteIp.substring(0, remoteIp.length() - 1) : remoteIp;
                    Map<Object, Object> avail = bugMapper.getAvail(deviceid);
                    String preRemoteIp = avail == null ? "" : ObjectUtil.getString(avail.get("ip"), "", WEB_SM_LIMIT);
                    String[] currip = preRemoteIp.split(",");
                    String[] preRemoteIpArr = remoteIp2.split(",");
                    Arrays.sort(currip);
                    Arrays.sort(preRemoteIpArr);
                    Integer scanCount = Integer.valueOf(ObjectUtil.getInt(device.get("aScanCount"), 0));
                    String code = ObjectUtil.getString(serverInfo.get("code"), state.equalsIgnoreCase("NO_RESPONSE") ? "000" : "200");
                    String devConf = ObjectUtil.getString(device.get("confContent"), "");
                    String serverIp = "";
                    if (StringUtils.isNotBlank(devConf)) {
                        Map<String, Object> confContent = (Map) JsonUtil.MAPPER.readValue(devConf, Map.class);
                        serverIp = ObjectUtil.getString(confContent.get("serverIp"), "");
                    }
                    bugMapper.insertAvail(deviceid, code, Integer.valueOf(("0".equals(code) || "000".equals(code)) ? 1 : 2), 0, 0, Integer.valueOf((int) (ObjectUtil.getDouble(serverInfo.get("totalTime"), 0.0d) * 1000.0d)), Integer.valueOf(scanCount.intValue() == 1 ? 0 : (StringUtils.isNotBlank(serverIp) && serverIp.contains("0.0.0.0")) ? 0 : Arrays.equals(currip, preRemoteIpArr) ? 0 : 1), remoteIp2, preRemoteIp, ObjectUtil.getString(serverInfo.get("server"), "", 1000), ObjectUtil.getString(serverInfo.get("xPowerdBy"), "", 200), ObjectUtil.getString(serverInfo.get("title"), "", 5000));
                    if ("0".equals(code) || "000".equals(code)) {
                        List<Map<String, Object>> slogs = new ArrayList<>();
                        Map<String, Object> slog = new HashMap<>();
                        slog.put("scantype", "webscan");
                        slog.put("name", "不可访问");
                        slog.put("VulType", "web");
                        slog.put("level", "高危");
                        slog.put("url", ObjectUtil.getString(device.get("ip"), ""));
                        slog.put("time", new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
                        slogs.add(slog);
                        SysLogJob.addBugs(slogs);
                    }
                }
                if (StringUtils.isNotBlank(error)) {
                    status = 3;
                }
                if (status != null && (status.intValue() == 2 || status.intValue() == 3)) {
                    boolean bl = false;
                    Map<Object, Object> noAccess = bugMapper.getAvailNoAccess(deviceid);
                    if (noAccess != null && noAccess.size() > 0) {
                        if (bugMapper.availNoAccessCount(deviceid) >= 50) {
                            bugMapper.delOneNoAccessSta(deviceid);
                        }
                        bugMapper.insertAvailSta(noAccess);
                        bl = true;
                    }
                    if (!bl && (availMap = bugMapper.getAvail(deviceid)) != null && availMap.size() > 0) {
                        if (bugMapper.availStaCount(deviceid) >= 10) {
                            bugMapper.delOneAvailSta(deviceid);
                        }
                        bugMapper.insertAvailSta(availMap);
                    }
                    Map<String, Object> queryAvailUrl = alarmlogMapper.queryAvailUrl(deviceid);
                    if (MapUtils.isNotEmpty(queryAvailUrl)) {
                        alarmlogMapper.delAlarmlogByTime();
                        alarmlogMapper.insert(queryAvailUrl);
                    }
                    if (ObjectUtil.getInt(task.getAlarmType(), 0) == 1 || StringUtils.isNotBlank(ObjectUtil.getString(device.get("val2"), ""))) {
                        device.put("webScanType", "avail");
                        AlermJob.alermDevice(device);
                    }
                }
                bugMapper.updTaskAvail(deviceid, error, status, Double.valueOf(totalProgress), new Date());
                session.commit();
                if (status != null && ((status.intValue() == 2 || status.intValue() == 3) && (waitingDev = bugMapper.getAvailWaitingDev(deviceid)) != null && waitingDev.size() > 0)) {
                    Integer devid = ObjectUtil.getInt(waitingDev.get("id"));
                    if (ObjectUtil.getInt(waitingDev.get("scanType")).intValue() == 2) {
                        String dest = ObjectUtil.getString(waitingDev.get("dest"), "");
                        int aStatus = ObjectUtil.getInt(waitingDev.get("availStatus")).intValue();
                        if (dest.contains("avail") && aStatus == 4) {
                            webService.startAvail(devid);
                        }
                    }
                }
                if (session != null) {
                    session.close();
                }
            } catch (Exception e) {
                if (session != null) {
                    session.rollback();
                }
                LOG.error("网站引擎同步出错", e);
                if (session != null) {
                    session.close();
                }
            }
        } catch (Throwable th) {
            if (session != null) {
                session.close();
            }
            throw th;
        }
    }

    public static void webTamperScanSync(Map<String, Object> device) {
        if (device == null) {
            return;
        }
        SqlSession session = null;
        try {
            try {
                WebMapper webMapper = (WebMapper) InstanceUtil.newDaoInstance(WebMapper.class);
                Integer deviceid = ObjectUtil.getInt(device.get("id"));
                int urlOffset = ObjectUtil.getInt(device.get("tamperOffset")).intValue();
                Task task = webMapper.getTaskById(ObjectUtil.getInt(device.get("taskId")));
                Map<String, Object> conf = (Map) JsonUtil.MAPPER_ESCAPE_HTML.readValue(task.getConfContent(), HashMap.class);
                String taskDest = task.getDest();
                Map<String, Object> engResult = engine.webGetResult(ObjectUtil.getString(device.get("tamperEngineid"), (String) null), ObjectUtil.getInt(device.get("tamperEid"), 0), urlOffset, 200, 0, 0, 0, 0);
                Map<String, Object> result = (Map) engResult.get("result");
                String error = ObjectUtil.getString(engResult.get("error"), (String) null);
                Map<String, Object> progress = (Map) result.get("progress");
                double totalProgress = ObjectUtil.getDouble(progress.get("totalProgress"), 0.0d);
                List<Map<String, Object>> urls = (List) result.get("urls");
                session = MybatisUtil.sqlSessionFactory.openSession(true);
                WebBugMapper bugMapper = (WebBugMapper) session.getMapper(WebBugMapper.class);
                Integer tScanCount = Integer.valueOf(ObjectUtil.getInt(device.get("tScanCount"), 0));
                if (urls != null && urls.size() > 0) {
                    for (Map<String, Object> m : urls) {
                        String urlAddr = ObjectUtil.getString(m.get("url"), (String) null, 5000);
                        if (urlAddr != null) {
                            if (tScanCount.intValue() == 1) {
                                String path = deviceid + "/" + System.nanoTime();
                                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_URL, path), ObjectUtil.getString(m.get("rawData"), ""), "UTF-8");
                                bugMapper.saveUrlTamper(deviceid, urlAddr, ObjectUtil.getString(m.get("method"), ""), ObjectUtil.getString(m.get("body"), "", 65535), path, ObjectUtil.getString(m.get("type"), ""), ObjectUtil.getString(m.get("hash"), ""), ObjectUtil.getString(m.get("md5"), ""), ObjectUtil.getString(m.get("title"), "", 2000), ObjectUtil.getString(m.get("code"), ""), ObjectUtil.getString(m.get("referer"), "", 5000));
                            } else {
                                String path2 = deviceid + "/" + System.nanoTime();
                                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_URL, TEMP_FILE_NAME + path2), ObjectUtil.getString(m.get("rawData"), ""), "UTF-8");
                                bugMapper.saveUrlTamper1(deviceid, urlAddr, ObjectUtil.getString(m.get("method"), ""), ObjectUtil.getString(m.get("body"), "", 65535), path2, ObjectUtil.getString(m.get("type"), ""), ObjectUtil.getString(m.get("hash"), ""), ObjectUtil.getString(m.get("md5"), ""), ObjectUtil.getString(m.get("title"), "", 2000), ObjectUtil.getString(m.get("code"), ""), ObjectUtil.getString(m.get("referer"), "", 5000));
                            }
                        }
                    }
                }
                Integer status = null;
                if (totalProgress >= 100.0d) {
                    status = 2;
                    bugMapper.delTamper(deviceid);
                    FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_TAMPER, new StringBuilder().append(deviceid).toString()));
                    if (taskDest.contains("tamper") && bugMapper.getUrlTamperCount(deviceid) > 0 && bugMapper.getUrlTamper2Count(deviceid) > 0) {
                        Double similarity = Double.valueOf(ObjectUtil.getDouble(task.getSimilarity(), 90.0d));
                        String tamper = ObjectUtil.getString(task.getTamper(), "");
                        String whiteList = ObjectUtil.getString(conf.get("whiteList"), "");
                        try {
                            getTamper2Result(bugMapper, deviceid, similarity, tamper, whiteList);
                        } catch (Exception e) {
                            LOG.error("计算篡改出错", e);
                        }
                    }
                    if (tScanCount.intValue() != 1) {
                        bugMapper.delUrlTamper(deviceid);
                        bugMapper.copyUrlTamper(deviceid);
                        bugMapper.delUrlTamper2(deviceid);
                        FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_URL, new StringBuilder().append(deviceid).toString()));
                        File f = new File(Constant.WEB_SCAN_URL, TEMP_FILE_NAME + deviceid);
                        f.renameTo(new File(Constant.WEB_SCAN_URL, new StringBuilder().append(deviceid).toString()));
                    }
                    if (ObjectUtil.getInt(task.getAlarmType(), 0) == 1 || StringUtils.isNotBlank(ObjectUtil.getString(device.get("val2"), ""))) {
                        device.put("webScanType", "tamper");
                        AlermJob.alermDevice(device);
                    }
                }
                if (StringUtils.isNotBlank(error)) {
                    status = 3;
                }
                bugMapper.updTaskTamper(deviceid, error, status, Double.valueOf(totalProgress), Integer.valueOf(urls == null ? 0 : urls.size()), totalProgress >= 100.0d ? new Date() : null);
                session.commit();
                if (status != null && (status.intValue() == 2 || status.intValue() == 3)) {
                    Map<String, Object> waitingDev = bugMapper.getWaitingDev(deviceid);
                    if (waitingDev != null && waitingDev.size() > 0) {
                        Integer devid = ObjectUtil.getInt(waitingDev.get("id"));
                        if (ObjectUtil.getInt(waitingDev.get("scanType")).intValue() == 1) {
                            webService.start(devid, ObjectUtil.getInt(waitingDev.get("taskId")));
                        } else {
                            String dest = ObjectUtil.getString(waitingDev.get("dest"), "");
                            int bugStatus = ObjectUtil.getInt(waitingDev.get("status")).intValue();
                            int tamperStatus = ObjectUtil.getInt(waitingDev.get("tamperStatus")).intValue();
                            if (dest.contains("bug") && bugStatus == 4) {
                                webService.startWeb(devid);
                            }
                            if (dest.contains("tamper") && tamperStatus == 4) {
                                webService.startTamper(devid);
                            }
                        }
                    }
                    List<Map<String, Object>> queryTamperUrl = alarmlogMapper.queryTamperUrl(deviceid);
                    if (CollectionUtils.isNotEmpty(queryTamperUrl)) {
                        alarmlogMapper.delAlarmlogByTime();
                        alarmlogMapper.batchInsert(queryTamperUrl);
                    }
                }
                if (session != null) {
                    session.close();
                }
            } catch (Exception e2) {
                if (session != null) {
                    session.rollback();
                }
                LOG.error("网站引擎同步出错", e2);
                if (session != null) {
                    session.close();
                }
            }
        } catch (Throwable th) {
            if (session != null) {
                session.close();
            }
            throw th;
        }
    }

    public static void webBugScanSync(Map<String, Object> device) {
        if (device == null) {
            return;
        }
        SqlSession session = null;
        try {
            try {
                WebMapper webMapper = (WebMapper) InstanceUtil.newDaoInstance(WebMapper.class);
                Integer deviceid = ObjectUtil.getInt(device.get("id"));
                int urlOffset = ObjectUtil.getInt(device.get("offset1")).intValue();
                int offset2 = ObjectUtil.getInt(device.get("offset2")).intValue();
                int offset3 = ObjectUtil.getInt(device.get("offset3")).intValue();
                Task task = webMapper.getTaskById(ObjectUtil.getInt(device.get("taskId")));
                String taskDest = task.getDest();
                Map<String, Object> engResult = engine.webGetResult(ObjectUtil.getString(device.get("engineId"), (String) null), ObjectUtil.getInt(device.get("localEid"), 0), urlOffset, 200, offset2, 200, offset3, WEB_SM_LIMIT);
                Map<String, Object> result = (Map) engResult.get("result");
                String error = ObjectUtil.getString(engResult.get("error"), (String) null);
                Map<String, Object> progress = (Map) result.get("progress");
                double totalProgress = ObjectUtil.getDouble(progress.get("totalProgress"), 0.0d);
                List<Map<String, Object>> urls = (List) result.get("urls");
                List<Map<String, Object>> sites = (List) result.get("sites");
                List<Map<String, Object>> scanResult = (List) result.get("issues");
                SqlSession session2 = MybatisUtil.sqlSessionFactory.openSession(true);
                WebBugMapper bugMapper = (WebBugMapper) session2.getMapper(WebBugMapper.class);
                WebPoliciesMapper webPoliciesMapper = (WebPoliciesMapper) session2.getMapper(WebPoliciesMapper.class);
                Integer scanCount = Integer.valueOf(ObjectUtil.getInt(device.get("scanCount"), 0));
                String topic = configMapper.getValueByName("kafka_topic");
                String address = configMapper.getValueByName("kafka_address");
                if (urls != null) {
                    try {
                        if (urls.size() > 0) {
                            for (Map<String, Object> m : urls) {
                                String urlAddr = ObjectUtil.getString(m.get("url"), (String) null);
                                if (urlAddr != null) {
                                    if (scanCount.intValue() == 1) {
                                        String path = deviceid + "/" + System.nanoTime();
                                        FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_BUGURL, path), ObjectUtil.getString(m.get("rawData"), ""), "UTF-8");
                                        bugMapper.saveUrl(deviceid, urlAddr, ObjectUtil.getString(m.get("method"), ""), ObjectUtil.getString(m.get("body"), "", 65535), path, ObjectUtil.getString(m.get("type"), ""), ObjectUtil.getString(m.get("hash"), ""), ObjectUtil.getString(m.get("md5"), ""), ObjectUtil.getString(m.get("title"), "", 2000), ObjectUtil.getString(m.get("code"), ""), ObjectUtil.getString(m.get("referer"), "", 5000));
                                    } else {
                                        String path2 = deviceid + "/" + System.nanoTime();
                                        FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_BUGURL, TEMP_FILE_NAME + path2), ObjectUtil.getString(m.get("rawData"), ""), "UTF-8");
                                        bugMapper.saveUrl1(deviceid, urlAddr, ObjectUtil.getString(m.get("method"), ""), ObjectUtil.getString(m.get("body"), "", 65535), path2, ObjectUtil.getString(m.get("type"), ""), ObjectUtil.getString(m.get("hash"), ""), ObjectUtil.getString(m.get("md5"), ""), ObjectUtil.getString(m.get("title"), "", 2000), ObjectUtil.getString(m.get("code"), ""), ObjectUtil.getString(m.get("referer"), "", 5000));
                                    }
                                }
                            }
                        }
                    } catch (Exception e) {
                        LOG.error("网站扫描同步出错", e);
                    }
                }
                if ((taskDest.contains("bug") || taskDest.contains("horse") || taskDest.contains("tamper") || taskDest.contains("keyword") || taskDest.contains("fish")) && scanResult != null && scanResult.size() > 0) {
                    for (Map<String, Object> m2 : scanResult) {
                        String name = ObjectUtil.getString(m2.get("name"), (String) null);
                        String urlAddr2 = ObjectUtil.getString(m2.get("url"), (String) null, 3000);
                        int fishcount = 0;
                        if (name != null && urlAddr2 != null) {
                            String value = ObjectUtil.getString(m2.get("value"), "");
                            if ("FishingInspection".equals(name)) {
                                try {
                                    List<Map<String, Object>> bugValues = (List) JsonUtil.MAPPER_ESCAPE_HTML.readValue(value, ArrayList.class);
                                    List<Map<String, Object>> bugList = new ArrayList<>();
                                    for (Map<String, Object> bugValue : bugValues) {
                                        String rowData = ObjectUtil.getString(bugValue.get("rawData"), "");
                                        if (!"".equals(rowData)) {
                                            String vpath = deviceid + "/" + System.nanoTime();
                                            FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_BUG, scanCount.intValue() > 1 ? TEMP_FILE_NAME + vpath : vpath), rowData, "UTF-8");
                                            bugValue.put("rawData", vpath);
                                        }
                                        String imgData = ObjectUtil.getString(bugValue.get("imgData"), "");
                                        if (!"".equals(imgData)) {
                                            String imgpath = deviceid + "/" + System.nanoTime();
                                            FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_BUG, scanCount.intValue() > 1 ? TEMP_FILE_NAME + imgpath : imgpath), imgData, "UTF-8");
                                            bugValue.put("imgData", imgpath);
                                        }
                                        bugList.add(bugValue);
                                        if (StringUtils.isNotBlank(topic) && StringUtils.isNotBlank(address)) {
                                            try {
                                                Map<String, Object> data = new HashMap<>();
                                                Map<String, Object> policy = (Map) PoliciesSingleton.getInstance().getPolicesConfig().get(name);
                                                data.put("bug_id", name);
                                                data.put("bug_name", ObjectUtil.getString(policy.get("name"), ""));
                                                data.put("bug_desct", ObjectUtil.getString(policy.get("desc"), ""));
                                                data.put("bug_ip", ObjectUtil.getString(bugValue.get("domain"), ""));
                                                data.put("bug_type", ObjectUtil.getString(policy.get("owasp"), ""));
                                                data.put("bug_level", WEB_LEVEL.get(ObjectUtil.getString(policy.get("level"), "")));
                                                data.put("bug_status", 1);
                                                KafkaUtil.getInstance().send(data);
                                            } catch (Exception e2) {
                                                LOG.error("kafka发送失败：", e2);
                                            }
                                        }
                                    }
                                    fishcount = bugList.size();
                                    value = JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(bugList);
                                } catch (Exception e3) {
                                    LOG.error("json转换错误（可能是字符串截取长度不够导致）", e3);
                                }
                            }
                            String testPath = deviceid + "/" + System.nanoTime();
                            String originPath = deviceid + "/" + System.nanoTime();
                            if (scanCount.intValue() == 1) {
                                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_BUG, testPath), ObjectUtil.getString(m2.get("testRawData"), ""), "UTF-8");
                                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_BUG, originPath), ObjectUtil.getString(m2.get("originRawData"), ""), "UTF-8");
                                bugMapper.saveResult(deviceid, name, urlAddr2, ObjectUtil.getString(m2.get("testUrl"), "", 50000), ObjectUtil.getString(value, "", 50000), testPath, originPath, Integer.valueOf(fishcount));
                            } else {
                                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_BUG, TEMP_FILE_NAME + testPath), ObjectUtil.getString(m2.get("testRawData"), ""), "UTF-8");
                                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_BUG, TEMP_FILE_NAME + originPath), ObjectUtil.getString(m2.get("originRawData"), ""), "UTF-8");
                                bugMapper.saveResult1(deviceid, name, urlAddr2, ObjectUtil.getString(m2.get("testUrl"), "", 50000), ObjectUtil.getString(value, "", 50000), testPath, originPath, Integer.valueOf(fishcount));
                            }
                            if (StringUtils.isNotBlank(topic) && StringUtils.isNotBlank(address)) {
                                try {
                                    Map<String, Object> policy2 = (Map) PoliciesSingleton.getInstance().getPolicesConfig().get(name);
                                    Map<String, Object> data2 = new HashMap<>();
                                    data2.put("bug_id", name);
                                    data2.put("bug_name", ObjectUtil.getString(policy2.get("name"), ""));
                                    data2.put("bug_desct", ObjectUtil.getString(policy2.get("desc"), ""));
                                    data2.put("bug_ip", urlAddr2);
                                    data2.put("bug_type", ObjectUtil.getString(policy2.get("owasp"), ""));
                                    data2.put("bug_level", WEB_LEVEL.get(ObjectUtil.getString(policy2.get("level"), "")));
                                    data2.put("bug_status", 1);
                                    KafkaUtil.getInstance().send(data2);
                                } catch (Exception e4) {
                                    LOG.error("kafka发送失败：", e4);
                                }
                            }
                        }
                    }
                }
                Integer status = null;
                if (totalProgress >= 100.0d) {
                    status = 2;
                    if (scanCount.intValue() != 1) {
                        bugMapper.delUrl(deviceid);
                        List<Map<String, Object>> oldBug = bugMapper.getBugByDev(deviceid);
                        bugMapper.delBug(deviceid);
                        bugMapper.copyUrl2ToUrl(deviceid);
                        bugMapper.copyResult(deviceid);
                        bugMapper.delUrl2(deviceid);
                        bugMapper.delBug2(deviceid);
                        if (oldBug != null && oldBug.size() > 0) {
                            bugMapper.insertBug2(oldBug);
                        }
                        FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_BUGURL, new StringBuilder().append(deviceid).toString()));
                        File furl = new File(Constant.WEB_SCAN_BUGURL, TEMP_FILE_NAME + deviceid);
                        furl.renameTo(new File(Constant.WEB_SCAN_BUGURL, new StringBuilder().append(deviceid).toString()));
                        FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_BUG, OLD_BUG_NAME + deviceid));
                        File oldBugFile = new File(Constant.WEB_SCAN_BUG, new StringBuilder().append(deviceid).toString());
                        oldBugFile.renameTo(new File(Constant.WEB_SCAN_BUG, OLD_BUG_NAME + deviceid));
                        File fbug = new File(Constant.WEB_SCAN_BUG, TEMP_FILE_NAME + deviceid);
                        fbug.renameTo(new File(Constant.WEB_SCAN_BUG, new StringBuilder().append(deviceid).toString()));
                    }
                    Date currDate = new Date();
                    for (Map<Object, Object> bugCount : bugMapper.bugStatistics(deviceid)) {
                        bugMapper.saveStatistics(deviceid, Integer.valueOf(ObjectUtil.getInt(bugCount.get("type"), 0)), ObjectUtil.getLong(bugCount.get("num"), 0L), currDate);
                    }
                    FtpUtil.reportUpload(task, device, (String) IReport.REPORT_CHK.get("web"), "web");
                    List<Map<String, Object>> webbugs = bugMapper.getBugsForLog(deviceid);
                    for (Map<String, Object> map : webbugs) {
                        Map<String, Object> policies = webPoliciesMapper.getPoliciesById(ObjectUtil.getString(map.get("id"), ""));
                        if (policies != null) {
                            map.put("owasp", ObjectUtil.getString(policies.get("owasp"), ""));
                            map.put("cve", ObjectUtil.getString(policies.get("cve"), ""));
                            map.put("cnnvd", ObjectUtil.getString(policies.get("cnnvd"), ""));
                            map.put("cnvd", ObjectUtil.getString(policies.get("cnvd"), ""));
                            map.put("cvss", ObjectUtil.getString(policies.get("cvss"), ""));
                            map.put("desct", ObjectUtil.getString(policies.get("desc"), ""));
                            map.put("sugg", ObjectUtil.getString(policies.get("advice"), ""));
                        }
                    }
                    String suyan_sendReport_ftp = configMapper.getValueByName("suyanSendFtp_" + task.getId());
                    if (StringUtils.isNotBlank(suyan_sendReport_ftp) && "yes".equalsIgnoreCase(suyan_sendReport_ftp)) {
                        task.setName(String.valueOf(task.getName().trim()) + "_wvss");
                        task.setFtpReportType("html");
                        FtpUtil.sendReport(task, ObjectUtil.getString(device.get("id"), ""), (String) IReport.REPORT_CHK.get("web"), "web");
                        task.setFtpReportType("doc");
                        FtpUtil.sendReport(task, ObjectUtil.getString(device.get("id"), ""), (String) IReport.REPORT_CHK.get("web"), "web");
                        task.setFtpReportType("pdf");
                        FtpUtil.sendReport(task, ObjectUtil.getString(device.get("id"), ""), (String) IReport.REPORT_CHK.get("web"), "web");
                        task.setFtpReportType("xls");
                        FtpUtil.sendReport(task, ObjectUtil.getString(device.get("id"), ""), (String) IReport.REPORT_CHK.get("web"), "web");
                        task.setFtpReportType("xml");
                        FtpUtil.sendReport(task, ObjectUtil.getString(device.get("id"), ""), (String) IReport.REPORT_CHK.get("web"), "web");
                    }
                    if (StringUtils.isNotBlank(topic) && StringUtils.isNotBlank(address)) {
                        try {
                            Map<String, Object> data3 = new HashMap<>();
                            data3.put("ip", ObjectUtil.getString(device.get("ip"), ""));
                            KafkaUtil.getInstance().send(data3);
                        } catch (Exception e5) {
                            LOG.error("kafka发送失败：", e5);
                        }
                    }
                    SysLogJob.addBugs(bugMapper.getBugsForLog(deviceid));
                    if (ObjectUtil.getInt(task.getAlarmType(), 0) == 1 || StringUtils.isNotBlank(ObjectUtil.getString(device.get("val2"), ""))) {
                        AlermJob.alermDevice(device);
                    }
                }
                if (StringUtils.isNotBlank(error)) {
                    status = 3;
                }
                bugMapper.updTaskWebForTimer(deviceid, error, status, Double.valueOf(totalProgress), Integer.valueOf(urls == null ? 0 : urls.size()), Integer.valueOf(sites == null ? 0 : sites.size()), Integer.valueOf(scanResult == null ? 0 : scanResult.size()), totalProgress >= 100.0d ? new Date() : null, (String) null);
                session2.commit();
                if (status != null && (status.intValue() == 2 || status.intValue() == 3)) {
                    alarmlogMapper.delAlarmlogByTime();
                    List<Map<String, Object>> queryWebBug = alarmlogMapper.queryWebBug(deviceid);
                    if (CollectionUtils.isNotEmpty(queryWebBug)) {
                        alarmlogMapper.batchInsert(queryWebBug);
                    }
                    List<Map<String, Object>> queryDeadLink = alarmlogMapper.queryDeadLink(deviceid);
                    if (CollectionUtils.isNotEmpty(queryDeadLink)) {
                        alarmlogMapper.batchInsert(queryDeadLink);
                    }
                    List<Map<String, Object>> queryBadLink = alarmlogMapper.queryBadLink(deviceid);
                    if (CollectionUtils.isNotEmpty(queryBadLink)) {
                        alarmlogMapper.batchInsert(queryBadLink);
                    }
                    Map<String, Object> waitingDev = bugMapper.getWaitingDev(deviceid);
                    if (waitingDev != null && waitingDev.size() > 0) {
                        Integer devid = ObjectUtil.getInt(waitingDev.get("id"));
                        if (ObjectUtil.getInt(waitingDev.get("scanType")).intValue() == 1) {
                            webService.start(devid, ObjectUtil.getInt(waitingDev.get("taskId")));
                        } else {
                            String dest = ObjectUtil.getString(waitingDev.get("dest"), "");
                            int bugStatus = ObjectUtil.getInt(waitingDev.get("status")).intValue();
                            int tamperStatus = ObjectUtil.getInt(waitingDev.get("tamperStatus")).intValue();
                            if (dest.contains("bug") && bugStatus == 4) {
                                webService.startWeb(devid);
                            }
                            if (dest.contains("tamper") && tamperStatus == 4) {
                                webService.startTamper(devid);
                            }
                        }
                    }
                }
                if (session2 != null) {
                    session2.close();
                }
            } catch (Exception e6) {
                if (0 != 0) {
                    session.rollback();
                }
                LOG.error("网站引擎同步出错", e6);
                if (0 != 0) {
                    session.close();
                }
            }
        } catch (Throwable th) {
            if (0 != 0) {
                session.close();
            }
            throw th;
        }
    }

    public static void webScanSync(Map<String, Object> device) {
        Map<Object, Object> availMap;
        if (device == null) {
            return;
        }
        SqlSession session = null;
        try {
            try {
                WebMapper webMapper = (WebMapper) InstanceUtil.newDaoInstance(WebMapper.class);
                Integer deviceid = ObjectUtil.getInt(device.get("id"));
                int urlOffset = ObjectUtil.getInt(device.get("offset1")).intValue();
                int offset2 = ObjectUtil.getInt(device.get("offset2")).intValue();
                int offset3 = ObjectUtil.getInt(device.get("offset3")).intValue();
                Task task = webMapper.getTaskById(ObjectUtil.getInt(device.get("taskId")));
                Map<String, Object> engResult = engine.webGetResult(ObjectUtil.getString(device.get("engineId"), (String) null), ObjectUtil.getInt(device.get("localEid"), 0), urlOffset, 200, offset2, 200, offset3, WEB_SM_LIMIT);
                Map<String, Object> result = (Map) engResult.get("result");
                String error = ObjectUtil.getString(engResult.get("error"), (String) null);
                Map<String, Object> progress = (Map) result.get("progress");
                double totalProgress = ObjectUtil.getDouble(progress.get("totalProgress"), 0.0d);
                List<Map<String, Object>> urls = (List) result.get("urls");
                List<Map<String, Object>> sites = (List) result.get("sites");
                List<Map<String, Object>> scanResult = (List) result.get("issues");
                Map<String, Object> serverInfo = (Map) result.get("serverInfo");
                SqlSession session2 = MybatisUtil.sqlSessionFactory.openSession(true);
                WebBugMapper bugMapper = (WebBugMapper) session2.getMapper(WebBugMapper.class);
                WebPoliciesMapper webPoliciesMapper = (WebPoliciesMapper) session2.getMapper(WebPoliciesMapper.class);
                Integer scanCount = Integer.valueOf(ObjectUtil.getInt(device.get("scanCount"), 0));
                String topic = configMapper.getValueByName("kafka_topic");
                String address = configMapper.getValueByName("kafka_address");
                if (urlOffset == 0 && serverInfo != null) {
                    try {
                        String state = ObjectUtil.getString(serverInfo.get("state"), "ACCESSIBLE");
                        if (StringUtils.isNotBlank(state)) {
                            String remoteIp = ObjectUtil.getString(serverInfo.get("remoteIp"), "", WEB_SM_LIMIT);
                            String remoteIp2 = (StringUtils.isNotBlank(remoteIp) && ",".equals(remoteIp.substring(remoteIp.length() - 1))) ? remoteIp.substring(0, remoteIp.length() - 1) : remoteIp;
                            Map<Object, Object> avail = bugMapper.getAvail(deviceid);
                            String preRemoteIp = avail == null ? "" : ObjectUtil.getString(avail.get("ip"), "", WEB_SM_LIMIT);
                            String[] currip = preRemoteIp.split(",");
                            String[] preRemoteIpArr = remoteIp2.split(",");
                            Arrays.sort(currip);
                            Arrays.sort(preRemoteIpArr);
                            String code = ObjectUtil.getString(serverInfo.get("code"), state.equalsIgnoreCase("NO_RESPONSE") ? "000" : "200");
                            bugMapper.insertAvail(deviceid, code, Integer.valueOf(("0".equals(code) || "000".equals(code)) ? 1 : 2), 0, 0, Integer.valueOf((int) (ObjectUtil.getDouble(serverInfo.get("totalTime"), 0.0d) * 1000.0d)), Integer.valueOf(scanCount.intValue() == 1 ? 0 : Arrays.equals(currip, preRemoteIpArr) ? 0 : 1), remoteIp2, preRemoteIp, ObjectUtil.getString(serverInfo.get("server"), "", 1000), ObjectUtil.getString(serverInfo.get("xPowerdBy"), "", 200), ObjectUtil.getString(serverInfo.get("title"), "", 5000));
                        }
                    } catch (Exception e) {
                        LOG.error("网站扫描同步出错", e);
                    }
                }
                if (urls != null && urls.size() > 0) {
                    for (Map<String, Object> m : urls) {
                        String urlAddr = ObjectUtil.getString(m.get("url"), (String) null, 5000);
                        if (urlAddr != null) {
                            if (scanCount.intValue() == 1) {
                                String path = deviceid + "/" + System.nanoTime();
                                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_URL, path), ObjectUtil.getString(m.get("rawData"), ""), "UTF-8");
                                bugMapper.saveUrl(deviceid, urlAddr, ObjectUtil.getString(m.get("method"), ""), ObjectUtil.getString(m.get("body"), "", 65535), path, ObjectUtil.getString(m.get("type"), ""), ObjectUtil.getString(m.get("hash"), ""), ObjectUtil.getString(m.get("md5"), ""), ObjectUtil.getString(m.get("title"), "", 2000), ObjectUtil.getString(m.get("code"), ""), ObjectUtil.getString(m.get("referer"), "", 5000));
                            } else {
                                String path2 = deviceid + "/" + System.nanoTime();
                                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_URL, TEMP_FILE_NAME + path2), ObjectUtil.getString(m.get("rawData"), ""), "UTF-8");
                                bugMapper.saveUrl1(deviceid, urlAddr, ObjectUtil.getString(m.get("method"), ""), ObjectUtil.getString(m.get("body"), "", 65535), path2, ObjectUtil.getString(m.get("type"), ""), ObjectUtil.getString(m.get("hash"), ""), ObjectUtil.getString(m.get("md5"), ""), ObjectUtil.getString(m.get("title"), "", 2000), ObjectUtil.getString(m.get("code"), ""), ObjectUtil.getString(m.get("referer"), "", 5000));
                            }
                        }
                    }
                }
                if (scanResult != null && scanResult.size() > 0) {
                    for (Map<String, Object> m2 : scanResult) {
                        String name = ObjectUtil.getString(m2.get("name"), (String) null);
                        String urlAddr2 = ObjectUtil.getString(m2.get("url"), (String) null, 3000);
                        int fishcount = 0;
                        if ("FishingInspection".equalsIgnoreCase(name)) {
                            String fstr = ObjectUtil.getString(m2.get("value"), "");
                            if (StringUtils.isNotBlank(fstr)) {
                                try {
                                    List<Map<String, Object>> fishes = (List) JsonUtil.MAPPER.readValue(fstr, List.class);
                                    fishcount = fishes.size();
                                    Map<String, Object> policy = (Map) PoliciesSingleton.getInstance().getPolicesConfig().get(name);
                                    if (StringUtils.isNotBlank(topic) && StringUtils.isNotBlank(address)) {
                                        for (Map<String, Object> bugValue : fishes) {
                                            try {
                                                Map<String, Object> data = new HashMap<>();
                                                data.put("bug_id", name);
                                                data.put("bug_name", ObjectUtil.getString(policy.get("name"), ""));
                                                data.put("bug_desct", ObjectUtil.getString(policy.get("desc"), ""));
                                                data.put("bug_ip", ObjectUtil.getString(bugValue.get("domain"), ""));
                                                data.put("bug_type", ObjectUtil.getString(policy.get("owasp"), ""));
                                                data.put("bug_level", WEB_LEVEL.get(ObjectUtil.getString(policy.get("level"), "")));
                                                data.put("bug_status", 1);
                                                KafkaUtil.getInstance().send(data);
                                            } catch (Exception e2) {
                                                LOG.error("kafka发送失败：", e2);
                                            }
                                        }
                                    }
                                } catch (Exception e3) {
                                    LOG.error("", e3);
                                }
                            }
                        }
                        if (name != null && urlAddr2 != null) {
                            if (scanCount.intValue() == 1) {
                                String testPath = deviceid + "/" + System.nanoTime();
                                String originPath = deviceid + "/" + System.nanoTime();
                                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_BUG, testPath), ObjectUtil.getString(m2.get("testRawData"), ""), "UTF-8");
                                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_BUG, originPath), ObjectUtil.getString(m2.get("originRawData"), ""), "UTF-8");
                                bugMapper.saveResult(deviceid, name, urlAddr2, ObjectUtil.getString(m2.get("testUrl"), "", 50000), ObjectUtil.getString(m2.get("value"), "", 50000), testPath, originPath, Integer.valueOf(fishcount));
                            } else {
                                String testPath2 = deviceid + "/" + System.nanoTime();
                                String originPath2 = deviceid + "/" + System.nanoTime();
                                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_BUG, TEMP_FILE_NAME + testPath2), ObjectUtil.getString(m2.get("testRawData"), ""), "UTF-8");
                                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_BUG, TEMP_FILE_NAME + originPath2), ObjectUtil.getString(m2.get("originRawData"), ""), "UTF-8");
                                bugMapper.saveResult1(deviceid, name, urlAddr2, ObjectUtil.getString(m2.get("testUrl"), "", 50000), ObjectUtil.getString(m2.get("value"), "", 50000), testPath2, originPath2, Integer.valueOf(fishcount));
                            }
                            if (StringUtils.isNotBlank(topic) && StringUtils.isNotBlank(address)) {
                                try {
                                    Map<String, Object> policy2 = (Map) PoliciesSingleton.getInstance().getPolicesConfig().get(name);
                                    Map<String, Object> data2 = new HashMap<>();
                                    data2.put("bug_id", name);
                                    data2.put("bug_name", ObjectUtil.getString(policy2.get("name"), ""));
                                    data2.put("bug_desct", ObjectUtil.getString(policy2.get("desc"), ""));
                                    data2.put("bug_ip", urlAddr2);
                                    data2.put("bug_type", ObjectUtil.getString(policy2.get("owasp"), ""));
                                    data2.put("bug_level", WEB_LEVEL.get(ObjectUtil.getString(policy2.get("level"), "")));
                                    data2.put("bug_status", 1);
                                    KafkaUtil.getInstance().send(data2);
                                } catch (Exception e4) {
                                    LOG.error("kafka发送失败：", e4);
                                }
                            }
                        }
                    }
                }
                Integer status = null;
                if (totalProgress >= 100.0d) {
                    status = 2;
                    if (scanCount.intValue() != 1) {
                        bugMapper.delUrl(deviceid);
                        List<Map<String, Object>> oldBug = bugMapper.getBugByDev(deviceid);
                        bugMapper.delBug(deviceid);
                        bugMapper.copyUrl2ToUrl(deviceid);
                        bugMapper.copyResult(deviceid);
                        bugMapper.delUrl2(deviceid);
                        bugMapper.delBug2(deviceid);
                        if (oldBug != null && oldBug.size() > 0) {
                            bugMapper.insertBug2(oldBug);
                        }
                        FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_URL, new StringBuilder().append(deviceid).toString()));
                        File furl = new File(Constant.WEB_SCAN_URL, TEMP_FILE_NAME + deviceid);
                        furl.renameTo(new File(Constant.WEB_SCAN_URL, new StringBuilder().append(deviceid).toString()));
                        FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_BUG, OLD_BUG_NAME + deviceid));
                        File oldBugFile = new File(Constant.WEB_SCAN_BUG, new StringBuilder().append(deviceid).toString());
                        oldBugFile.renameTo(new File(Constant.WEB_SCAN_BUG, OLD_BUG_NAME + deviceid));
                        File fbug = new File(Constant.WEB_SCAN_BUG, TEMP_FILE_NAME + deviceid);
                        fbug.renameTo(new File(Constant.WEB_SCAN_BUG, new StringBuilder().append(deviceid).toString()));
                    }
                    Date currDate = new Date();
                    for (Map<Object, Object> bugCount : bugMapper.bugStatistics(deviceid)) {
                        bugMapper.saveStatistics(deviceid, Integer.valueOf(ObjectUtil.getInt(bugCount.get("type"), 0)), ObjectUtil.getLong(bugCount.get("num"), 0L), currDate);
                    }
                    boolean bl = false;
                    Map<Object, Object> noAccess = bugMapper.getAvailNoAccess(deviceid);
                    if (noAccess != null && noAccess.size() > 0) {
                        if (bugMapper.availNoAccessCount(deviceid) >= 50) {
                            bugMapper.delOneNoAccessSta(deviceid);
                        }
                        bugMapper.insertAvailSta(noAccess);
                        bl = true;
                    }
                    if (!bl && (availMap = bugMapper.getAvail(deviceid)) != null && availMap.size() > 0) {
                        if (bugMapper.availStaCount(deviceid) >= 10) {
                            bugMapper.delOneAvailSta(deviceid);
                        }
                        bugMapper.insertAvailSta(availMap);
                    }
                    alarmlogMapper.delAlarmlogByTime();
                    List<Map<String, Object>> queryWebBug = alarmlogMapper.queryWebBug(deviceid);
                    if (CollectionUtils.isNotEmpty(queryWebBug)) {
                        alarmlogMapper.batchInsert(queryWebBug);
                    }
                    List<Map<String, Object>> queryDeadLink = alarmlogMapper.queryDeadLink(deviceid);
                    if (CollectionUtils.isNotEmpty(queryDeadLink)) {
                        alarmlogMapper.batchInsert(queryDeadLink);
                    }
                    List<Map<String, Object>> queryBadLink = alarmlogMapper.queryBadLink(deviceid);
                    if (CollectionUtils.isNotEmpty(queryBadLink)) {
                        alarmlogMapper.batchInsert(queryBadLink);
                    }
                    Map<String, Object> queryAvailUrl = alarmlogMapper.queryAvailUrl(deviceid);
                    if (MapUtils.isNotEmpty(queryAvailUrl)) {
                        alarmlogMapper.insert(queryAvailUrl);
                    }
                    FtpUtil.reportUpload(task, device, (String) IReport.REPORT_CHK.get("web"), "web");
                    String suyan_sendReport_ftp = configMapper.getValueByName("suyanSendFtp_" + task.getId());
                    if (StringUtils.isNotBlank(suyan_sendReport_ftp) && "yes".equalsIgnoreCase(suyan_sendReport_ftp)) {
                        try {
                            String ftp_ip = configMapper.getValueByName("ftp_ip");
                            String ftp_username = configMapper.getValueByName("ftp_username");
                            String ftp_password = configMapper.getValueByName("ftp_password");
                            String ftp_file_path = configMapper.getValueByName("ftp_file_path");
                            int ftp_port = ObjectUtil.getInt(configMapper.getValueByName("ftp_port"), 21);
                            FTPClient client = FtpUtil.newFTPClient(ftp_ip, ftp_port, ftp_username, ftp_password);
                            if (StringUtils.isNotBlank(ftp_file_path)) {
                                FtpUtil.mkdirs(client, ftp_file_path);
                            }
                            FileUtils.writeStringToFile((File) null, new SuyanWebscan().report(task, device).asXML(), "UTF-8");
                            client.upload((File) null);
                        } catch (Exception e5) {
                            LOG.error("", e5);
                        }
                    }
                    List<Map<String, Object>> webbugs = bugMapper.getBugsForLog(deviceid);
                    for (Map<String, Object> map : webbugs) {
                        Map<String, Object> policies = webPoliciesMapper.getPoliciesById(ObjectUtil.getString(map.get("id"), ""));
                        if (policies != null) {
                            map.put("owasp", ObjectUtil.getString(policies.get("owasp"), ""));
                            map.put("cve", ObjectUtil.getString(policies.get("cve"), ""));
                            map.put("cnnvd", ObjectUtil.getString(policies.get("cnnvd"), ""));
                            map.put("cnvd", ObjectUtil.getString(policies.get("cnvd"), ""));
                            map.put("cvss", ObjectUtil.getString(policies.get("cvss"), ""));
                            map.put("desct", ObjectUtil.getString(policies.get("desc"), ""));
                            map.put("sugg", ObjectUtil.getString(policies.get("advice"), ""));
                        }
                    }
                    if (StringUtils.isNotBlank(topic) && StringUtils.isNotBlank(address)) {
                        try {
                            Map<String, Object> data3 = new HashMap<>();
                            data3.put("ip", ObjectUtil.getString(device.get("ip"), ""));
                            KafkaUtil.getInstance().send(data3);
                        } catch (Exception e6) {
                            LOG.error("kafka发送失败：", e6);
                        }
                    }
                    SysLogJob.addBugs(bugMapper.getBugsForLog(deviceid));
                    if (ObjectUtil.getInt(task.getAlarmType(), 0) == 1 || StringUtils.isNotBlank(ObjectUtil.getString(device.get("val2"), ""))) {
                        AlermJob.alermDevice(device);
                    }
                }
                if (StringUtils.isNotBlank(error)) {
                    status = 3;
                }
                Integer availStatus = status;
                if (totalProgress > 0.0d) {
                    availStatus = 2;
                }
                bugMapper.updTaskWeb(deviceid, error, status, availStatus, Double.valueOf(totalProgress), Integer.valueOf(urls == null ? 0 : urls.size()), Integer.valueOf(sites == null ? 0 : sites.size()), Integer.valueOf(scanResult == null ? 0 : scanResult.size()), totalProgress >= 100.0d ? new Date() : null, (String) null);
                session2.commit();
                if (status != null && (status.intValue() == 2 || status.intValue() == 3)) {
                    try {
                        webService.sbrOemXml(deviceid);
                    } catch (Exception e7) {
                        LOG.error("圣博润OEM", e7);
                    }
                    Map<String, Object> waitingDev = bugMapper.getWaitingDev(deviceid);
                    if (waitingDev != null && waitingDev.size() > 0) {
                        Integer devid = ObjectUtil.getInt(waitingDev.get("id"));
                        if (ObjectUtil.getInt(waitingDev.get("scanType")).intValue() == 1) {
                            webService.start(devid, ObjectUtil.getInt(waitingDev.get("taskId")));
                        } else {
                            String dest = ObjectUtil.getString(waitingDev.get("dest"), "");
                            int bugStatus = ObjectUtil.getInt(waitingDev.get("status")).intValue();
                            int tamperStatus = ObjectUtil.getInt(waitingDev.get("tamperStatus")).intValue();
                            if (dest.contains("bug") && bugStatus == 4) {
                                webService.startWeb(devid);
                            }
                            if (dest.contains("tamper") && tamperStatus == 4) {
                                webService.startTamper(devid);
                            }
                        }
                    }
                }
                if (session2 != null) {
                    session2.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    session.close();
                }
                throw th;
            }
        } catch (Exception e8) {
            if (0 != 0) {
                session.rollback();
            }
            LOG.error("网站引擎同步出错", e8);
            if (0 != 0) {
                session.close();
            }
        }
    }

    private static void getTamper2Result(WebBugMapper bugMapper, Integer deviceid, Double similarity, String tamper, String whiteList) throws Exception {
        if (whiteList != null) {
            whiteList = String.valueOf('\n') + whiteList + '\n';
        }
        addTamperContentData(bugMapper, bugMapper.getTamper2Content(deviceid), deviceid, whiteList, similarity);
        if (tamper.contains("imgMD5")) {
            addTamperImgData(bugMapper, bugMapper.getTamper2Img(deviceid), deviceid, whiteList);
        }
        if (tamper.contains("title")) {
            addTamperTitleData(bugMapper, bugMapper.getTamper2Title(deviceid), deviceid, whiteList);
        }
        if (tamper.contains("delLinkRemind")) {
            addTamperLinkData(bugMapper, bugMapper.getTamper2DelLink(deviceid), deviceid, 3);
        }
        if (tamper.contains("newLinkRemind")) {
            addTamperLinkData(bugMapper, bugMapper.getTamper2NewLink(deviceid), deviceid, 2);
        }
    }

    private static void addTamperContentData(WebBugMapper bugMapper, List<Map<String, Object>> data, Integer deviceid, String whiteList, Double similarity) throws Exception {
        for (Map<String, Object> m : data) {
            String url = ObjectUtil.getString(m.get("url"), "", 65535);
            if (whiteList == null || !whiteList.contains("\n" + url + "\n")) {
                String oldDataPath = ObjectUtil.getString(m.get("oldData"), "");
                String newDataPath = ObjectUtil.getString(m.get("newData"), "");
                byte[] oldDataBs = SecretUtil.base64Decoder(FileUtils.readFileToString(new File(Constant.WEB_SCAN_URL, TEMP_FILE_NAME + oldDataPath), "UTF-8"));
                byte[] newDataBs = SecretUtil.base64Decoder(FileUtils.readFileToString(new File(Constant.WEB_SCAN_URL, newDataPath), "UTF-8"));
                String oldData = readRespBody(oldDataBs);
                if (!StringUtils.isBlank(oldData)) {
                    String newData = readRespBody(newDataBs);
                    if (!StringUtils.isBlank(newData)) {
                        if (similarity == null || similarity.doubleValue() <= 0.0d) {
                            String oldPath = deviceid + "/" + System.nanoTime();
                            String newPath = deviceid + "/" + System.nanoTime();
                            FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_TAMPER, oldPath), oldData, "UTF-8");
                            FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_TAMPER, newPath), newData, "UTF-8");
                            bugMapper.insertTamper(deviceid, url, 4, oldPath, newPath);
                        } else if (ComputeTextUtil.similarDegree(oldData, newData) < similarity.doubleValue() / 100.0d) {
                            String oldPath2 = deviceid + "/" + System.nanoTime();
                            String newPath2 = deviceid + "/" + System.nanoTime();
                            FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_TAMPER, oldPath2), oldData, "UTF-8");
                            FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_TAMPER, newPath2), newData, "UTF-8");
                            bugMapper.insertTamper(deviceid, url, 4, oldPath2, newPath2);
                        }
                    }
                }
            }
        }
    }

    private static void addTamperImgData(WebBugMapper bugMapper, List<Map<String, Object>> data, Integer deviceid, String whiteList) throws Exception {
        for (Map<String, Object> m : data) {
            String url = ObjectUtil.getString(m.get("url"), "", 65535);
            if (whiteList == null || !whiteList.contains("\n" + url + "\n")) {
                String oldDataPath = ObjectUtil.getString(m.get("oldData"), "");
                String newDataPath = ObjectUtil.getString(m.get("newData"), "");
                byte[] oldDataBs = SecretUtil.base64Decoder(FileUtils.readFileToString(new File(Constant.WEB_SCAN_URL, TEMP_FILE_NAME + oldDataPath), "UTF-8"));
                byte[] newDataBs = SecretUtil.base64Decoder(FileUtils.readFileToString(new File(Constant.WEB_SCAN_URL, newDataPath), "UTF-8"));
                String oldData = readRespBody(oldDataBs);
                if (!StringUtils.isBlank(oldData)) {
                    String newData = readRespBody(newDataBs);
                    if (!StringUtils.isBlank(newData)) {
                        String oldPath = deviceid + "/" + System.nanoTime();
                        String newPath = deviceid + "/" + System.nanoTime();
                        FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_TAMPER, oldPath), oldData, "UTF-8");
                        FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_TAMPER, newPath), newData, "UTF-8");
                        bugMapper.insertTamper(deviceid, url, 1, oldPath, newPath);
                    }
                }
            }
        }
    }

    private static void addTamperLinkData(WebBugMapper bugMapper, List<Map<String, Object>> data, Integer deviceid, int type) throws Exception {
        byte[] newDataBs;
        byte[] oldDataBs;
        for (Map<String, Object> m : data) {
            String url = ObjectUtil.getString(m.get("url"), "", 65535);
            String oldDataPath = ObjectUtil.getString(m.get("oldData"), "");
            String newDataPath = ObjectUtil.getString(m.get("newData"), "");
            String oldPath = "";
            String newPath = "";
            if (!"".equals(oldDataPath) && (oldDataBs = SecretUtil.base64Decoder(FileUtils.readFileToString(new File(Constant.WEB_SCAN_URL, TEMP_FILE_NAME + oldDataPath), "UTF-8"))) != null && oldDataBs.length > 0) {
                String oldData = readRespBody(oldDataBs);
                if (!StringUtils.isBlank(oldData)) {
                    oldPath = deviceid + "/" + System.nanoTime();
                    FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_TAMPER, oldPath), oldData, "UTF-8");
                }
            }
            if (!"".equals(newDataPath) && (newDataBs = SecretUtil.base64Decoder(FileUtils.readFileToString(new File(Constant.WEB_SCAN_URL, newDataPath), "UTF-8"))) != null && newDataBs.length > 0) {
                String newData = readRespBody(newDataBs);
                if (!StringUtils.isBlank(newData)) {
                    newPath = deviceid + "/" + System.nanoTime();
                    FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_TAMPER, newPath), newData, "UTF-8");
                }
            }
            bugMapper.insertTamper(deviceid, url, type, oldPath, newPath);
        }
    }

    private static void addTamperTitleData(WebBugMapper bugMapper, List<Map<String, Object>> data, Integer deviceid, String whiteList) throws Exception {
        for (Map<String, Object> m : data) {
            String url = ObjectUtil.getString(m.get("url"), "", 65535);
            if (whiteList == null || !whiteList.contains("\n" + url + "\n")) {
                String oldData = ObjectUtil.getString(m.get("oldTitle"), "");
                String newData = ObjectUtil.getString(m.get("newTitle"), "");
                String oldPath = deviceid + "/" + System.nanoTime();
                String newPath = deviceid + "/" + System.nanoTime();
                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_TAMPER, oldPath), oldData, "UTF-8");
                FileUtils.writeStringToFile(new File(Constant.WEB_SCAN_TAMPER, newPath), newData, "UTF-8");
                bugMapper.insertTamper(deviceid, url, 0, oldPath, newPath);
            }
        }
    }

    private static String readRespBody(byte[] data) throws UnsupportedEncodingException {
        if (data == null) {
            return null;
        }
        byte[] reqhead = readD(data, 0);
        int orioffset = 0 + reqhead.length + 4;
        byte[] reqbody = readD(data, orioffset);
        if (reqbody == null) {
            return null;
        }
        int orioffset2 = orioffset + reqbody.length + 4;
        byte[] reshead = readD(data, orioffset2);
        byte[] resbody = subBytes(data, orioffset2 + reshead.length + 4);
        return new String(resbody, "utf8");
    }

    private static byte[] subBytes(byte[] src, int begin) {
        byte[] bs = new byte[src.length - begin];
        System.arraycopy(src, begin, bs, 0, bs.length);
        return bs;
    }

    private static byte[] readD(byte[] bs, int offset) {
        for (int i = offset; i < bs.length; i++) {
            if (i + 3 >= bs.length) {
                byte[] result = new byte[bs.length - offset];
                System.arraycopy(bs, offset, result, 0, result.length);
                return result;
            }
            if (((char) bs[i]) == '\r' && ((char) bs[i + 1]) == '\n' && ((char) bs[i + 2]) == '\r' && ((char) bs[i + 3]) == '\n') {
                byte[] result2 = new byte[i - offset];
                System.arraycopy(bs, offset, result2, 0, result2.length);
                return result2;
            }
        }
        return null;
    }
}
